//============================================================================
// FILE: C_CoreProcess.h
//
// TYPE: C++CLASS 
// DESCRIPTION: entête des processus "moteur" de CONTROL DIESE
// 
// AUTHORS: Rellier (INRA/UBIA, Toulouse)
// REFERENCE : "Fondements ontologiques des systèmes pilotés"
//             R. Martin-Clouaire, J.-P. Rellier (INRA/UBIA, Toulouse)
//=X===============X=============================X============================

#ifndef _C_COREPROCESS_HH
#define _C_COREPROCESS_HH

// SYSTEM INCLUDES
//
//#include <>                                    //

// PROJECT INCLUDES
//
#include "C_CoreTypes.h"

/**@name Processus prédéfinis liés aux activités
\begin{itemize} \item Directive d'inclusion : {\tt \#include C\_CoreProcess.h} \end{itemize}
*/ 
//@{

// X///////////////X/////////////////////////////X////////////////////////////

/**@name Révision de l'état des activités
\index{UpdateSituationProcess}Un processus de cette classe est automatiquement associé (avec la directive EXEC) à un événement du type {\bf UpdateSituationEvent} par l'appel à la fonction {\bf PostUpdateSituationEvent} (voir page \pageref{defEventUpdateSituation}). L'objet passé en paramètre est le contrôleur ({\bf Manager}.
*/
//@{
        ///
class UpdateSituationProcess : public DiscreteProcess
{
public:
          // Constructeur de base. Affecte comme entité opérée le 'manager' de l''entité simulée' de la simulation courante. Ladite 'entité simulée' doit donc avoir été désignée (par {\bf SimulatedEntity}).
   UpdateSituationProcess();       
 };
//@}

// X///////////////X/////////////////////////////X////////////////////////////
/**@name Redéfinition des instructions à exécuter
\index{MakeInstructionListProcess}Un processus de cette classe est automatiquement associé (avec la directive EXEC) à un événement du type {\bf MakeInstructionListEvent} par l'appel à la fonction {\bf PostMakeInstructionListEvent} (voir page \pageref{defEventMakeInstructionList}). L'objet passé en paramètre est un bloc activités-ressources ({\bf ActivitiesResourceBlock} ou bien l'ensemble des blocs de la stratégie.
*/
//@{
        ///
class MakeInstructionListProcess : public DiscreteProcess
{
public:
          // Constructeur de base. 
   MakeInstructionListProcess(Entity* arb);       
 };
//@}

// X///////////////X/////////////////////////////X////////////////////////////
/**@name Redéfinition des instructions à exécuter et arrêt des progressions d'opération
\index{MakeInstructionListProcess2}Un processus de cette classe est automatiquement associé (avec la directive EXEC) à un événement du type {\bf MakeInstructionListEvent} par l'appel à la fonction {\bf PostMakeInstructionListEvent2} (voir page \pageref{defEventMakeInstructionList}). L'objet passé en paramètre est un bloc activités-ressources ({\bf ActivitiesResourceBlock} ou bien l'ensemble des blocs de la stratégie.
*/
//@{
        ///
class MakeInstructionListProcess2 : public DiscreteProcess
{
public:
          // Constructeur de base. 
   MakeInstructionListProcess2(Entity* arb);       
 };
//@}

// X///////////////X/////////////////////////////X////////////////////////////
/**@name Lancement des exécutions concurrentes des opérations
\index{ActInstructionListProcess}Un processus de cette classe est automatiquement associé (avec la directive EXEC) à un événement du type {\bf ActInstructionListEvent} par l'appel à la fonction {\bf PostActInstructionListEvent} (voir page \pageref{defEventActInstructionList}). L'objet passé en paramètre est un paquet d'instructions exécutables ({\bf PackOfExecutableInstructions}).
*/
//@{
        ///
class ActInstructionListProcess : public DiscreteProcess
{
public:
          // Constructeur de base. 
   ActInstructionListProcess(DescriptedEntity* pack); 
 };
//@}

// X///////////////X/////////////////////////////X////////////////////////////

/**@name Exécution continue d'une opération
\label{defProceedOperationProcess}\index{ProceedOperationProcess}Un processus de cette classe est automatiquement créé et associé (avec les directives INIT puis PROCEED) à un événement du type {\bf SetInitialStateAndProceed} par un appel à {\bf PostInitAndProceedEvent} (voir manuel \D) dans la méthode {\bf ActInstructionList} du {\em système opérant} (voir page \pageref{defActInstructionList}). Le mécanisme standard de \Db est appliqué. \\

Au moment de la création du processus, un contenu est donné aux méthodes standard des processus continus. 
\begin{itemize}
\item Un appel à {\bf SetInitialize} affecte la fonction {\bf C\_ProceedOperationProcess\_initializeProcess\_Body} comme corps de la méthode prédéfinie {\bf InitializeProcess}. 
\item Un appel à {\bf SetStop} affecte la fonction {\bf C\_ProceedOperationProcess\_stopProcess\_Body} comme corps de la méthode prédéfinie {\bf StopProcess}. 
\item Un appel à {\bf SetGoOneStepForward} affecte comme corps de la méthode prédéfinie {\bf GoOneStepForwardProcess}, et en fonction de la valeur du descripteur OT\_SPEED\_MODE de l'opération concernée :
  \begin{itemize}
    \item la fonction {\bf C\_proceedUnitOperation\_goOneStepForwardProcess\_Body} (valeur UNIT), 
    \item la fonction {\bf C\_proceedQuantityOperation\_goOneStepForwardProcess\_Body} (valeur QUANTITY),  
    \item ou la fonction {\bf C\_proceedTimeOperation\_goOneStepForwardProcess\_Body} (valeur GRAD) 
  \end{itemize}
\end{itemize}
Lire des explications complémentaires page \pageref{defActInstructionList}.
*/
//@{
        ///
class ProceedOperationProcess : public ContinuousProcess
{
public:
          // Constructeur.
   ProceedOperationProcess(Operation*);       
 };
//@}

// X///////////////X/////////////////////////////X////////////////////////////

/**@name Augmentation du degré de progression d'une opération
\label{defAugmentOperationPercentAchievedProcess}\index{AugmentOperationPercentAchievedProcess}

Un processus de cette classe est automatiquement créé et associé (avec les directives INIT puis PROCEED) à un événement du type {\bf SetInitialStateAndProceed} par un appel à {\bf PostInitAndProceedEvent} (voir manuel \D) dans la méthode {\bf ActInstructionList} du {\em système opérant} (voir page \pageref{defActInstructionList}). Le mécanisme standard de \Db est appliqué. \\

Au moment de la création du processus, un contenu est donné aux méthodes standard des processus continus. 
\begin{itemize}
\item Un appel à {\bf SetInitialize} affecte la fonction {\bf C\_ProceedOperationProcess\_initializeProcess\_Body} comme corps de la méthode prédéfinie {\bf InitializeProcess}. 
\item Un appel à {\bf SetStop} affecte la fonction {\bf C\_ProceedOperationProcess\_stopProcess\_Body} comme corps de la méthode prédéfinie {\bf StopProcess}. 
\item Un appel à {\bf SetGoOneStepForward} affecte comme corps de la méthode prédéfinie {\bf GoOneStepForwardProcess}, et en fonction de la valeur du descripteur OT\_SPEED\_MODE de l'opération concernée :
  \begin{itemize}
    \item la fonction {\bf C\_proceedUnitOperation\_goOneStepForwardProcess\_Body} (valeur UNIT), 
    \item la fonction {\bf C\_proceedQuantityOperation\_goOneStepForwardProcess\_Body} (valeur QUANTITY),  
    \item ou la fonction {\bf C\_proceedTimeOperation\_goOneStepForwardProcess\_Body} (valeur GRAD) 
  \end{itemize}
\end{itemize}
Lire des explications complémentaires page \pageref{defActInstructionList}.
*/
//@{
        ///
class AugmentOperationPercentAchievedProcess : public DiscreteProcess
{
public:
          // Constructeur.
   AugmentOperationPercentAchievedProcess(Operation*);       
 };
//@}

//@}  // fin processus activités

// X///////////////X/////////////////////////////X////////////////////////////

/**@name Processus prédéfinis liés aux ressources */
//@{

/**@name Immobilisation d'une ressource
\index{ResourceImmobilizationProcess}Un processus de cette classe est automatiquement associé (avec la directive EXEC) à un événement du type {\bf ResourceImmobilizationEvent}.
*/
//@{
        ///
class ResourceImmobilizationProcess : public DiscreteProcess
{
public:
          // Constructeur de base. 
   ResourceImmobilizationProcess();       
 };
//@}

// X///////////////X/////////////////////////////X////////////////////////////

/**@name Mobilisation d'une ressource

\index{ResourceMobilizationProcess}Un processus de cette classe est automatiquement associé (avec la directive EXEC) à un événement du type {\bf ResourceMobilizationEvent}.
*/
//@{
        ///
class ResourceMobilizationProcess : public DiscreteProcess
{
public:
          // Constructeur de base. 
   ResourceMobilizationProcess();       
 };
//@}

// X///////////////X/////////////////////////////X////////////////////////////

//@}  // fin processus ressources

// X///////////////X/////////////////////////////X////////////////////////////

/**@name Processus prédéfinis liés aux fichiers de données */  // + JPR 081027
//@{

/**@name Lecture d'un fichier de données séquentielles, avec mémoire et prédiction
\index{UpdateSituationProcess}Un processus de cette classe offre les services de lecture d'un fichier de données séquentielles, comme un processus {\bf ReadSequentialDataFileProcess}. En outre, ses méthodes d'initialisation (surchargeable) et d'avancée construisent et gèrent, respectivement, une mémoire des enregistrements déjà lus, et une prédiction sur les prochains enregistrements correspondant à des instants futurs.\\

\label{procLectureBufDF}L'usage de cette sous-classe nécessite la déclaration préalable d'une classe de {\bf BufferizedDataFile} : le processus ne pourra lire que des fichiers physiques qui auront fait l'objet d'une instantiation de cette classe (fichier logique). Le symbole de la sous-classe en question de {\bf BufferizedDataFile} est une propriété du processus (accessible par {\bf FileClassId()}).\\

Sont prédéfinies dans DIESE les méthodes d'initialisation, d'avancée et d'arr\^et du processus.\\

C'est la méthode prédéfinie d'initialisation qui instancie le fichier logique {\bf BufferizedDataFile} et l'associe au fichier physique voulu, de la même manière que pour les {\bf SequentialDataFile}. De même, le développeur peut remplacer la méthode d'initialisation prédéfinie par une autre, plus adaptée à ses besoins.\\

La méthode prédéfinie d'arr\^et est héritée de la classe mère sans surchargement.\\

La méthode prédéfinie d'avancée appelle la méthode {\bf ReadNextEnrgt} sur l'instance de {\bf BufferizedDataFile}, et la méthode d'arr\^et seulement si la fin du fichier est atteinte. Puis, le cas échéant, la méthode {\bf PostRead}, qui est définie, spécifiée et utilisé de la même manière que pour les {\bf ReadSequentialDataFileProcess}. Comme indiqué dans la documentation des {\bf BufferizedDataFile}, le corps de la méthode {\bf ReadNextEnrgt} est complètement prédéfini dans \CD, et il fait appel au corps de la méthode {\bf ScanNextEnrgt} qui doit être codé par le développeur.\\

Pour mettre en oeuvre un processus de cette classe, on l'encapsule, comme c'est la règle générale, dans un événement. Les tois possibilités listées pour les {\bf ReadSequentialDataFileProcess} sont encore actives ici.\\

*/
//@{
        ///
class ReadBufferizedDataFileProcess : public ReadSequentialDataFileProcess
{
public:
  // Constructeur de base. 
  ReadBufferizedDataFileProcess(); 
  /// Constructeur ave affectation du symbole de classe, qui sera celui du fichier lu.
  ReadBufferizedDataFileProcess(UserProcessId, char*);                    
  /// Constructeur par copie profonde, y compris des méthodes.  Invoque le constructeur par copie de la classe-mère.
  ReadBufferizedDataFileProcess(const ReadBufferizedDataFileProcess&); // _no swig_    
 };
//@}

/**@name Corps de méthode prédéfinie pour la lecture de fichiers séquentiels à mémoire

Cete méthode est invoquée automatiquement dès lors qu'on a déclaré, et inséré dans l'agenda, un processus de la classe {\bf ReadBufferizedDataFileProcess}.\\

Si cete méthode ne recoit pas un nouveau corps par surchargement, c'est la forme prédéfinie dans le moteur qui est activée.\\

On rappelle ici que ce processus de lecture possède aussi, par héritage, une autre méthode, {\bf PostRead}, dont aucune forme standard de corps n'est incluse dans le moteur. Il revient donc au modélisateur de coder ce corps (sur la base des explications dans la documentation du processus de lecture), et d'affecter ce corps par un appel à {\bf SetPostRead}. */
//@{
         /// Initialisation de la lecture du fichier. Récupère les noms du fichier traité par le processus, et en établit le chemin complet. Puis ouvre le fichier et saute éventuellement le nombre approprié de lignes en début du fichier.
void readBufferizedDataFileProcess_initializeProcess_Body(ProcessMethod*); // _no swig_
         // Lecture du premier enregistrement non lu du fichier. Invoque le corps d'une éventuelle méthode {\bf PostRead}.
void readBufferizedDataFileProcess_goOneStepForwardProcess_Body(ProcessMethod*); // _no swig_
         // 
//void readSequentialDataFileProcess_stopProcess_Body(ProcessMethod*); // _no swig_

//@} // fin fonctions

// X///////////////X/////////////////////////////X////////////////////////////

//@}  // fin processus fichiers

//@}  // ouverture dans C_CoreEvent

#endif  // _C_COREPROCESS_HH
