//============================================================================
// FILE: C_CoreVariableDescriptor.h
//
// TYPE: C++CLASS
// DESCRIPTION: entête des divers descripteurs variables de Control-Diese
// 
// AUTHORS: Baali/Rellier (INRA/UBIA, Toulouse)
// REFERENCE : "Fondements ontologiques des systèmes pilotés"
//             R. Martin-Clouaire, J.-P. Rellier (INRA/UBIA, Toulouse)
//=X===============X=============================X============================

#ifndef _C_COREVARDESCRIPTOR_HH
#define _C_COREVARDESCRIPTOR_HH

// SYSTEM INCLUDES
//

// PROJECT INCLUDES
//
#include "VariableDescriptor.h"

/**@name Les descripteurs variables
\begin{tabular}{lllll}
type&nom C++&symbole de classe&nom de classe&sens de la valeur \\
&MinNumberOfReplications&MIN_NUMBER_OF_REPLICATIONS&minNumberOfReplications& \\
&MaxNumberOfReplications&MAX_NUMBER_OF_REPLICATIONS&maxNumberOfReplications& \\
&BegDate&BEG_DATE&begDate& \\
&EndDate&END_DATE&endDate& \\
&LastRestartingDate&LAST_RESTARTING_DATE&lastRestartingDate& \\
&MinBegDate&MIN_BEG_DATE&minBegDate& \\
&MaxBegDate&MAX_BEG_DATE&maxBegDate& \\
&ReplicationMinBegDate&REPLICATION_MIN_BEG_DATE&replicationMinBegDate& \\
&ReplicationMaxBegDate&REPLICATION_MAX_BEG_DATE&replicationMaxBegDate& \\
&MinEndDate&MIN_END_DATE&minEndDate& \\
&MaxEndDate&MAX_END_DATE&maxEndDate& \\
&Situation&SITUATION&situation& \\
&ReadyToRun&READY_TO_RUN&readyToRun& \\
&LastProceedOperationDate&LAST_PROCEED_OPERATION_DATE&lastProceedOperationDate& \\
&OpenToOpenDelays&OPEN_TO_OPEN_DELAYS&openToOpenDelays& \\
&CloseToOpenDelays&CLOSE_TO_OPEN_DELAYS&closeToOpenDelays& \\
&CloseToCloseDelays&CLOSE_TO_CLOSE_DELAYS&closeToCloseDelays& \\
&OpenToCloseDelays&OPEN_TO_CLOSE_DELAYS&openToCloseDelays& \\
&ClosedYetValidated&CLOSED_YET_VALIDATED&closedYetValidated& \\
&ReplicationCounter&REPLICATION_COUNTER&replicationCounter& \\
&ValidationFrom&VALIDATION_FROM&validationFrom& \\
&LastValidationRequest&LAST_VALIDATION_REQUEST&lastValidationRequest& \\
&LastValidationDirection&LAST_VALIDATION_DIRECTION&lastValidationDirection& \\
&LastValidationOrigine&LAST_VALIDATION_ORIGINE&lastValidationOrigine& \\
&IsWaitingValid&IS_WAITING_VALID&isWaitingValid& \\
&IsOpenValid&IS_OPEN_VALID&isOpenValid& \\
&IsClosedValid&IS_CLOSED_VALID&isClosedValid& \\
&IsOpeningPredicateChecked&IS_OPENING_PREDICATE_CHECKED&isOpeningPredicateChecked& \\
&IsOpeningPredicateNotFalse&IS_OPENING_PREDICATE_NOT_FALSE&isOpeningPredicateNotFalse& \\
&RootTab&ROOT_TAB&rootTab& \\
&NbInvolvedEntities&NB_INVOLVED_ENTITIES&nbInvolvedEntities& \\
&OperationClassId&OPERATION_CLASS_ID&operationClassId& \\
&OperationClassName&OPERATION_CLASS_NAME&operationClassName& \\
&GoalList&GOAL_LIST&goalList& \\
&EntitySpecReferenceClassId&ENTITY_SPEC_REFERENCE_CLASS_ID&entitySpecReferenceClassId& \\
&EntitySpecReferenceClassName&ENTITY_SPEC_REFERENCE_CLASS_NAME&entitySpecReferenceClassName& \\
&OperatedObjectSpecAttribute&OPERATED_OBJECT_SPEC_ATTRIBUTE&operatedObjectSpecAttribute& \\
&DestinationSpecAttribute&DESTINATION_SPEC_ATTRIBUTE&destinationSpecAttribute& \\
&TransferInformationAttribute&TRANSFER_INFORMATION_ATTRIBUTE&transferInformationAttribute& \\
&OperationSpecAttribute&OPERATION_SPEC_ATTRIBUTE&operationSpecAttribute& \\
&PerformerSpecAttribute&PERFORMER_SPEC_ATTRIBUTE&performerSpecAttribute& \\
&AllocatedOperation&ALLOCATED_OPERATION&allocatedOperation& \\
&InstructionSetConsistency&INSTRUCTION_SET_CONSISTENCY&instructionSetConsistency& \\
&InstructionSetMaximality&INSTRUCTION_SET_MAXIMALITY&instructionSetMaximality& \\
&IsAllocated&IS_ALLOCATED&isAllocated& \\
&Duration&DURATION&duration& \\
&NetDuration&NET_DURATION&netDuration& \\
&AchievementDegree&ACHIEVEMENT_DEGREE&achievementDegree& \\
&ActivityClosingThreshold&ACTIVITY_CLOSING_THRESHOLD&activityClosingThreshold& \\
&InstructionContainer&INSTRUCTION_CONTAINER&instructionContainer& \\
&RequiredResources&REQUIRED_RESOURCES&requiredResources& \\
&Power&POWER&power& \\
&AvailabilityStatus&AVAILABILITY_STATUS&availabilityStatus& \\
&ConstrainedEntityClassId&CONSTRAINED_ENTITY_CLASS_ID&constrainedEntityClassId& \\
&IntCurrentLevel&INT_CURRENT_LEVEL&intCurrentLevel& \\
&FloatCurrentLevel&FLOAT_CURRENT_LEVEL&floatCurrentLevel& \\
&ResourceId&RESOURCE_ID&resourceId& \\
&IntInCapacity&INT_IN_CAPACITY&intInCapacity& \\
&IntOutCapacity&INT_OUT_CAPACITY&intOutCapacity& \\
&FloatInCapacity&FLOAT_IN_CAPACITY&floatInCapacity& \\
&FloatOutCapacity&FLOAT_OUT_CAPACITY&floatOutCapacity& \\
&DeveloppedList&DEVELOPPED_LIST&developpedList& \\
&ListToOperate&LIST_TO_OPERATE&listToOperate& \\
&PreExpandedList&PRE_EXPANDED_LIST&preExpandedList& \\
&FullyOperatedBy&FULLY_OPERATED_BY&fullyOperatedBy& \\
&NonOperatedEntityList&NON_OPERATED_ENTITY_LIST&nonOperatedEntityList& \\
&OperatedEntityList&OPERATED_ENTITY_LIST&operatedEntityList& \\
&NonOperatedIntQuantity&NON_OPERATED_INT_QUANTITY&nonOperatedIntQuantity& \\
&NonOperatedFloatQuantity&NON_OPERATED_FLOAT_QUANTITY&nonOperatedFloatQuantity& \\
&OperatedIntQuantity&OPERATED_INT_QUANTITY&operatedIntQuantity& \\
&OperatedFloatQuantity&OPERATED_FLOAT_QUANTITY&operatedFloatQuantity& \\
&NonOperatedProportion&NON_OPERATED_PROPORTION&nonOperatedProportion& \\
&OperatedProportion&OPERATED_PROPORTION&operatedProportion& \\
&SpecifiedOperation&SPECIFIED_OPERATION&specifiedOperation& \\
&ActivityContainerList&ACTIVITY_CONTAINER_LIST&activityContainerList& \\
&WeightAttribute&WEIGHT_ATTRIBUTE&weightAttribute& \\
&ActivityActionMode&ACTIVITY_ACTION_MODE&activityActionMode& \\

\end{tabular}
*/
//@{

//=X===============X=============================X============================
// Activity/Activities/ActivitiSet
//............................................................................

class MinNumberOfReplications : public IntVariableDescriptor
{
public:
  MinNumberOfReplications();
};

class MaxNumberOfReplications : public IntVariableDescriptor
{
public:
  MaxNumberOfReplications();
};

class BegDate : public IntVariableDescriptor  
{
public:
   BegDate();
};

class EndDate : public IntVariableDescriptor
{
public:
   EndDate();                                 
};

class LastRestartingDate : public IntVariableDescriptor
{
public:
   LastRestartingDate();                                 
};

class MinBegDate : public IntVariableDescriptor
{
public:
   MinBegDate();                                    
};

class MaxBegDate : public IntVariableDescriptor
{
public:
   MaxBegDate();                                    
};

class ReplicationMinBegDate : public IntVariableDescriptor
{
public:
   ReplicationMinBegDate();                                    
};

class ReplicationMaxBegDate : public IntVariableDescriptor
{
public:
   ReplicationMaxBegDate();                                    
};

class MinEndDate : public IntVariableDescriptor
{
public:
   MinEndDate();                                    
};

class MaxEndDate : public IntVariableDescriptor
{
public:
   MaxEndDate();                                    
};

class Situation : public IntVariableDescriptor
{
public:
  Situation();
};

class ReadyToRun : public IntVariableDescriptor
{
public:
  ReadyToRun();
};

class LastProceedOperationDate : public IntVariableDescriptor
{
public:
  LastProceedOperationDate();
};

class OpenToOpenDelays : public IntDomainVariableDescriptor
{
public:
  OpenToOpenDelays();
};

class CloseToOpenDelays : public IntDomainVariableDescriptor
{
public:
  CloseToOpenDelays();
};
class CloseToCloseDelays : public IntDomainVariableDescriptor
{
public:
  CloseToCloseDelays();
};

class OpenToCloseDelays : public IntDomainVariableDescriptor
{
public:
  OpenToCloseDelays();
};

class ClosedYetValidated : public IntVariableDescriptor
{
public:
  ClosedYetValidated();
};

class ReplicationCounter : public  IntVariableDescriptor
{
public:
  ReplicationCounter();
};

class ValidationFrom : public  EntityTabVariableDescriptor
{
public:
  ValidationFrom();
};

class LastValidationRequest : public  IntVariableDescriptor
{
public:
  LastValidationRequest();
};

class LastValidationDirection : public  IntVariableDescriptor
{
public:
  LastValidationDirection();
};

class LastValidationOrigine : public  EntityVariableDescriptor
{
public:
  LastValidationOrigine();
};

class IsWaitingValid : public  IntVariableDescriptor
{
public:
  IsWaitingValid();
};

class IsOpenValid : public  IntVariableDescriptor
{
public:
  IsOpenValid();
};

class IsClosedValid : public  IntVariableDescriptor
{
public:
  IsClosedValid();
};

class IsOpeningPredicateChecked : public  IntVariableDescriptor
{
public:
  IsOpeningPredicateChecked();
};

class IsOpeningPredicateNotFalse : public  IntVariableDescriptor
{
public:
  IsOpeningPredicateNotFalse();
};

class RootTab : public  EntityTabVariableDescriptor
{
public:
  RootTab();
};

class NbInvolvedEntities : public IntVariableDescriptor
{
public:
   NbInvolvedEntities();                                 
};

class OperatedObjectSpecAttribute : public  EntityVariableDescriptor
{
public:
  OperatedObjectSpecAttribute();
};

class DestinationSpecAttribute : public  EntityVariableDescriptor
{
public:
  DestinationSpecAttribute();
};

class TransferInformationAttribute : public  EntityVariableDescriptor
{
public:
  TransferInformationAttribute();
};

class OperationSpecAttribute : public  EntityVariableDescriptor
{
public:
  OperationSpecAttribute();
};

class PerformerSpecAttribute : public  EntityVariableDescriptor
{
public:
  PerformerSpecAttribute();
};

class AllocatedOperation : public  EntityVariableDescriptor
{
public:
  AllocatedOperation();
};

class OperationClassId : public IntVariableDescriptor
{
 public:
  OperationClassId();
};

class OperationClassName : public StringVariableDescriptor
{
 public:
  OperationClassName();
};

class GoalList : public  EntityTabVariableDescriptor
{
public:
  GoalList();
};

class DynamicActivityToContinue : public IntVariableDescriptor
{
 public:
  DynamicActivityToContinue();
};

//=X===============X=============================X============================
// ActivitySet
//............................................................................

class InstructionSetConsistency : public  IntVariableDescriptor
{
public:
  InstructionSetConsistency();
};

class InstructionSetMaximality : public  IntVariableDescriptor
{
public:
  InstructionSetMaximality();
};

class IsAllocated : public  IntVariableDescriptor
{
public:
  IsAllocated();
};

//=X===============X=============================X============================
// Operation
//............................................................................

class Duration : public IntVariableDescriptor
{
public:
  Duration();
};

class NetDuration : public IntVariableDescriptor
{
public:
  NetDuration();
};

class AchievementDegree : public FloatVariableDescriptor
{
public:
  AchievementDegree();
};

class ActivityClosingThreshold : public FloatVariableDescriptor
{
public:
  ActivityClosingThreshold();
};

class InstructionContainer : public  EntityVariableDescriptor
{
public:
  InstructionContainer();
};

class RequiredResources : public EntityTabVariableDescriptor
{
public:
  RequiredResources();
};

//=X===============X=============================X============================
// Resource
//............................................................................

class Power : public FloatVariableDescriptor
{
public:
  Power();
};

class AvailabilityStatus : public IntVariableDescriptor
{
public:
  AvailabilityStatus();
};

class IntCurrentLevel : public IntVariableDescriptor
{
public:
  IntCurrentLevel();
};

class FloatCurrentLevel : public FloatVariableDescriptor
{
public:
  FloatCurrentLevel();
};



//=X===============X=============================X============================
// ResourceAllocation
//............................................................................

class IntInCapacity : public  IntVariableDescriptor
{
 public:
  IntInCapacity();
};

class IntOutCapacity : public  IntVariableDescriptor
{
 public:
  IntOutCapacity();
};

class FloatInCapacity : public  FloatVariableDescriptor
{
 public:
  FloatInCapacity();
};

class FloatOutCapacity : public  FloatVariableDescriptor
{
 public:
  FloatOutCapacity();
};



//=X===============X=============================X============================
// ResourceCapacity
//............................................................................

class ResourceId : public  IntVariableDescriptor
{
 public:
  ResourceId();
};


//=X===============X=============================X============================
// Resource constraint
//............................................................................

class ConstrainedEntityClassId : public IntVariableDescriptor
{
public:
  ConstrainedEntityClassId();
};



//=X===============X=============================X============================
// Spec
//............................................................................

class EntitySpecReferenceClassId : public IntVariableDescriptor
{
 public:
  EntitySpecReferenceClassId();
};

class EntitySpecReferenceClassName : public StringVariableDescriptor
{
 public:
  EntitySpecReferenceClassName();
};

class EntitySpecReferentEntity : public EntityVariableDescriptor
{
 public:
  EntitySpecReferentEntity();
};

class DeveloppedList : public  EntityTabVariableDescriptor
{
 public:
  DeveloppedList();
};

class ListToOperate : public  EntityTabVariableDescriptor
{
 public:
  ListToOperate();
};

class PreExpandedList : public  EntityTabVariableDescriptor
{
 public:
  PreExpandedList();
};

class FullyOperatedBy : public  EntityTabVariableDescriptor
{
 public:
  FullyOperatedBy();
};

class NonOperatedEntityList : public  EntityTabVariableDescriptor
{
 public:
  NonOperatedEntityList();
};

class OperatedEntityList : public  EntityTabVariableDescriptor
{
 public:
  OperatedEntityList();
};

class NonOperatedIntQuantity : public  IntVariableDescriptor
{
 public:
  NonOperatedIntQuantity();
};

class NonOperatedFloatQuantity : public  FloatVariableDescriptor
{
 public:
  NonOperatedFloatQuantity();
};

class OperatedIntQuantity : public  IntVariableDescriptor
{
 public:
  OperatedIntQuantity();
};

class OperatedFloatQuantity : public  FloatVariableDescriptor
{
 public:
  OperatedFloatQuantity();
};

class NonOperatedProportion : public  FloatVariableDescriptor
{
 public:
  NonOperatedProportion();
};

class OperatedProportion : public  FloatVariableDescriptor
{
 public:
  OperatedProportion();
};

class SpecifiedOperation : public  EntityVariableDescriptor
{
 public:
  SpecifiedOperation();
};

class ActivityContainerList : public  EntityTabVariableDescriptor
{
 public:
  ActivityContainerList();
};

//=X===============X=============================X============================
// Operator
//............................................................................

class OperatorState : public IntVariableDescriptor
{
public:
  OperatorState();
};

//=X===============X=============================X============================
// Tool
//............................................................................

class ToolState : public IntVariableDescriptor
{
public:
  ToolState();
};


//=X===============X=============================X============================
// Criterion
//............................................................................

class WeightAttribute : public FloatVariableDescriptor
{ 
public:
  WeightAttribute();
};


//=X===============X=============================X============================
// Goal
//............................................................................

class ActivityActionMode : public IntVariableDescriptor
{
public:
  ActivityActionMode();
};

//=X===============X=============================X============================
// System
//............................................................................

class MemoryScope : public IntVariableDescriptor
{
public:
  MemoryScope();
};

class PredictionScope : public IntVariableDescriptor
{
public:
  PredictionScope();
};

//@} // fin V
//@} // fin C+V



#endif  // _C_COREVARDESCRIPTOR_HH
