//============================================================================
// FILE: ParserFunction.h
//
// TYPE: C++ CLASS
// DESCRIPTION: entête des fonctions de parsing
// 
// AUTHORS: Rellier/Remion (INRA/UBIA, Toulouse)
//=X===============X=============================X============================

#ifndef _PARSER_HH
#define _PARSER_HH

// ---------------
// SYSTEM INCLUDES
// ---------------
#include <stdio.h>

// ----------------
// PROJECT INCLUDES
// ----------------
#include "CoreTypes.h"   // pour pEntityList
#include "File.h" 

// ---------------
// EXTERNAL REFERENCES
// ---------------

extern LexicalInputFile* pFatherFile;  // -+JPR 120307
extern LexicalInputFile* pCurrentFile;

extern int yyparse();   // int : + JPR 020121 pour compile g++ 2.9.5 Linux

// Fonction qui établit la valeur de variables globales correspondant
// aux paramètres, dans InitSimulation immédiatement après la lecture des 
// paramètres.
//
// Cette fonction est réalisée dans le code de l'application
// (e.g. UserFunction), et est donc déclarée en extern au niveau de DIESE.
//
// Pour un paramètre entier dont les identifiants sont "a1" et "a2", la 
// variable doit s'appeler 'gIntParam_a1_a2_', et l'initialisation dans 
// InitParameterGlobalVariables se fait par :
//
// int gIntParam_a1_a2_ = GetIntParameterValue("a1", "a2");
//
// Les variables globales sont à déclarer en extern dans UserTypes.h
//
extern void InitParameterGlobalVariables();
extern void (*pInitParameterGlobalVariables)();  // _no swig_ 

void Assign_InitParameterGlobalVariablesFunction(void (*f)());

// note D5.9 : désormais,
// pInitParameterGlobalVariables() est invoqué en fin de ParseParameterFile,
// cad dès qu'on est en mesure de faire les Get... ParameterValue.
// On pourrait invoquer directement InitParameterGlobalVariables().
// Le couple d'instructions Assign_Init...() + pInitParameterGlobalVariables()
// est maintenu pour compatibilité avec les bases développées sous D5.8,
// lesquelles contiennent ces instructions dans InitSimulation().
   
// JPR 070420 : suppression 'D_Init' 'C_Init' et remplacement par unique 'Init'
// old : D_Init et C_Init sont déclarées ici et réalisées vides dans 
//       ParserFunction.cc
//       D_Init et C_Init sont ensuite surchargées dans UserFunction.cc
// Sous Linux, c'est le C_Init de UserFunction qui est invoqué (OK)
// Sous Windows/Cygwin, c'est le C_Init de ParserFunction.cc qui est invoqué !
// ==>
// new : Init est déclaré ici et n'est réalisé que dans l'application :
//       mainCompileModule pour bdiese et cdiese
//       UserFunction.cc pour une KBS
// Cela entraîne le non usage de la possibilité de linker une base construite
// préalablement sous bdiese dans une base cdiese, car il y aurait alors deux
// fonctions Init
// Une prochaine version des outils doit acter ce non usage en supprimant la
// possibilité.

// ---------------
// EXTERNAL FUNCTIONS
// ---------------
//@Man: fonctions
//@{

       ///\index{fonctions!ParseExpeFile}\label{foncParseExpeFile} 
void ParseExpeFile(char* nomFic);

       ///\index{fonctions!ParseSimulationFile}\label{foncParseSimulationFile} 
void ParseSimulationFile(char* nomFic);

	///\index{fonctions!ParseDirectiveFile}\label{foncParseDirectiveFile} 
void ParseDirectiveFile(char* nomFic);

        /// Ouverture du fichier des paramètres, exploitation de son contenu puis fermeture du fichier. L'argument est le nom physique du fichier, exprimé relativement au répertoire d'exécution de la simulation. L'ouverture est réalisée par l'appel {\tt AssignPhysicalName(nom)}. La fermeture du fichier (par {\bf DeleteFileInstances}) est accompagnée de l'appel au destructeur de l'instance de {\bf LexicalInputFile}.\index{fonctions!ParseParameterFile}\label{foncParseParameterFile}
void   ParseParameterFile  (char* nom);

	/// Ouverture en lecture du fichier des spécifications de sortie, exploitation de son contenu puis fermeture du fichier. L'argument est le nom physique du fichier, exprimé relativement au répertoire d'exécution de la simulation. L'ouverture est réalisée par l'appel {\tt AssignPhysicalName(nom)}. L'appel à {\bf DeleteFileInstances} détruit les instances associées au fichier de spécification (entrée) et aux fichiers de sortie, et réalise la fermeture des fichiers externes.\index{fonctions!ParseOutputSpecFile}\label{foncParseOutputSpecFile}
void    ParseOutputSpecFile(char* nom);

	///\index{fonctions!ParseStructureFile}\label{foncParseStructureFile} 
void ParseStructureFile(char* nomFic);

	///
void Expe_Parser(LexicalInputFile*); // + JPR 120322
	///
void Simu_Parser(LexicalInputFile*); // modif JPR 120307
	///
void Directive_Parser(LexicalInputFile*); // modif JPR 120307
	///
void Param_Parser(LexicalInputFile*); // modif JPR 120307
	///
void OutputSpec_Parser(LexicalInputFile*); // modif JPR 120307
	///
void Structure_Parser(LexicalInputFile*); // modif JPR 120307

	//
void DisplayContainerEntityList(pEntityList*);
	
void NLd();        // NewLine
void TLd(char*);   // TraceLex

void NLi();        // NewLine
void TLi(char*);   // TraceLex

void NLp();        // NewLine
void TLp(char*);   // TraceLex

void NLs();        // NewLine
void TLs(char*);   // TraceLex

void NLe();        // NewLine
void TLe(char*);   // TraceLex

void NLo();        // NewLine
void TLo(char*);   // TraceLex
//@}  // fin fonctions


#endif  // _PARSER_HH
